pub struct Element {
pub name: String,
pub symbol: String,
pub atomic_number: u8,
pub atomic_mass: f64,
pub density: f64,
pub group: Option<u8>,
pub melting_point: Option<Value>,
pub boiling_point: Option<Value>,
}Expand description
Represents a chemical element with its properties from periodic table.
Fields
name: StringFull name of the chemical element
symbol: StringSymbol of the element
atomic_number: u8Atomic number of the element from periodic table
atomic_mass: f64Atomic mass of the element from periodic table
density: f64Density of the element.
group: Option<u8>Optional group number of the element in the periodic table.
melting_point: Option<Value>Optional melting point of the element.
boiling_point: Option<Value>Optional boiling point of the element.